@@ -47,7 +47,7 @@
 #include <sys/time.h>    /* for "struct timeval" */
 #include <sys/un.h>      /* for "struct sockaddr_un" */
 #include <netinet/in.h>  /* for "struct sockaddr_in[6]" */
-#include <sys/socket.h>  /* for "PF_XXX", "AF_XXX" and "SOCK_XXX" */
+#include <sys/socket.h>  /* for "PF_XXX", "AF_XXX", "SOCK_XXX" and "SHUT_XX" */
 #include <arpa/inet.h>   /* for "inet_XtoX" */
 
 /* include own API header */
@@ -90,6 +90,19 @@ const char sa_id[] = "OSSP sa";
 #define PF_INET6 AF_INET6
 #endif
 
+/* backward compatibility for SHUT_XX. Some platforms (like brain-dead
+   OpenUNIX) define those only if _XOPEN_SOURCE is defined, but unfortunately
+   then fail in their other vendor includes due to internal inconsistencies. */
+#if !defined(SHUT_RD)
+#define SHUT_RD 0
+#endif
+#if !defined(SHUT_WR)
+#define SHUT_WR 1
+#endif
+#if !defined(SHUT_RDWR)
+#define SHUT_RDWR 2
+#endif
+
 /* backward compatibility for ssize_t */
 #if defined(HAVE_CONFIG_H) && !defined(HAVE_SSIZE_T)
 #define ssize_t long
@@ -305,7 +318,7 @@ static int sa_mvxprintf(int (*output)(void *ctx, const char *buffer, size_t bufs
     int n;
     int bytes;
 
-    if (format == NULL || ap == NULL)
+    if (format == NULL)
         return -1;
     bytes = 0;
     while (*format != '\0') {
@@ -387,7 +400,7 @@ static int sa_mvsnprintf(char *buffer, size_t bufsize, const char *format, va_li
     int n;
     sa_mvsnprintf_cb_t ctx;
 
-    if (format == NULL || ap == NULL)
+    if (format == NULL)
         return -1;
     if (buffer != NULL && bufsize == 0)
         return -1;
@@ -1508,7 +1521,7 @@ sa_rc_t sa_accept(sa_t *sa, sa_addr_t **caddr, sa_t **csa)
         struct sockaddr_in6 sa6;
 #endif
     } sa_buf;
-    socklen_t sa_len;
+    socklen_t sa_size;
     int s;
     int i;
 
@@ -1539,14 +1552,14 @@ sa_rc_t sa_accept(sa_t *sa, sa_addr_t **caddr, sa_t **csa)
     }
 
     /* perform accept operation on underlying socket */
-    sa_len = sizeof(sa_buf);
-    if ((s = SA_SC_CALL_3(sa, accept, sa->fdSocket, (struct sockaddr *)&sa_buf, &sa_len)) == -1)
+    sa_size = sizeof(sa_buf);
+    if ((s = SA_SC_CALL_3(sa, accept, sa->fdSocket, (struct sockaddr *)&sa_buf, &sa_size)) == -1)
         return SA_RC(SA_ERR_SYS);
 
     /* create result address object */
     if ((rv = sa_addr_create(caddr)) != SA_OK)
         return SA_RC(rv);
-    if ((rv = sa_addr_s2a(*caddr, (struct sockaddr *)&sa_buf, sa_len)) != SA_OK) {
+    if ((rv = sa_addr_s2a(*caddr, (struct sockaddr *)&sa_buf, sa_size)) != SA_OK) {
         sa_addr_destroy(*caddr);
         return SA_RC(rv);
     }
@@ -1588,7 +1601,7 @@ sa_rc_t sa_getremote(sa_t *sa, sa_addr_t **raddr)
         struct sockaddr_in6 sa6;
 #endif
     } sa_buf;
-    socklen_t sa_len;
+    socklen_t sa_size;
 
     /* argument sanity check(s) */
     if (sa == NULL || raddr == NULL)
@@ -1603,14 +1616,14 @@ sa_rc_t sa_getremote(sa_t *sa, sa_addr_t **raddr)
         return SA_RC(SA_ERR_USE);
 
     /* determine remote address of underlying socket */
-    sa_len = sizeof(sa_buf);
-    if (getpeername(sa->fdSocket, (struct sockaddr *)&sa_buf, &sa_len) < 0)
+    sa_size = sizeof(sa_buf);
+    if (getpeername(sa->fdSocket, (struct sockaddr *)&sa_buf, &sa_size) < 0)
         return SA_RC(SA_ERR_SYS);
 
     /* create result address object */
     if ((rv = sa_addr_create(raddr)) != SA_OK)
         return SA_RC(rv);
-    if ((rv = sa_addr_s2a(*raddr, (struct sockaddr *)&sa_buf, sa_len)) != SA_OK) {
+    if ((rv = sa_addr_s2a(*raddr, (struct sockaddr *)&sa_buf, sa_size)) != SA_OK) {
         sa_addr_destroy(*raddr);
         return SA_RC(rv);
     }
@@ -1628,7 +1641,7 @@ sa_rc_t sa_getlocal(sa_t *sa, sa_addr_t **laddr)
         struct sockaddr_in6 sa6;
 #endif
     } sa_buf;
-    socklen_t sa_len;
+    socklen_t sa_size;
 
     /* argument sanity check(s) */
     if (sa == NULL || laddr == NULL)
@@ -1639,14 +1652,14 @@ sa_rc_t sa_getlocal(sa_t *sa, sa_addr_t **laddr)
         return SA_RC(SA_ERR_USE);
 
     /* determine local address of underlying socket */
-    sa_len = sizeof(sa_buf);
-    if (getsockname(sa->fdSocket, (struct sockaddr *)&sa_buf, &sa_len) < 0)
+    sa_size = sizeof(sa_buf);
+    if (getsockname(sa->fdSocket, (struct sockaddr *)&sa_buf, &sa_size) < 0)
         return SA_RC(SA_ERR_SYS);
 
     /* create result address object */
     if ((rv = sa_addr_create(laddr)) != SA_OK)
         return SA_RC(rv);
-    if ((rv = sa_addr_s2a(*laddr, (struct sockaddr *)&sa_buf, sa_len)) != SA_OK) {
+    if ((rv = sa_addr_s2a(*laddr, (struct sockaddr *)&sa_buf, sa_size)) != SA_OK) {
         sa_addr_destroy(*laddr);
         return SA_RC(rv);
     }
@@ -1966,8 +1979,8 @@ static int sa_writef_cb(void *_ctx, const char *buffer, size_t bufsize)
     sa_writef_cb_t *ctx = (sa_writef_cb_t *)_ctx;
 
     if ((ctx->rv = sa_write(ctx->sa, buffer, bufsize, &n)) != SA_OK)
-        n = -1;
-    return n;
+        return -1;
+    return (int)n;
 }
 
 /* write formatted string to socket (convinience function) */
@@ -2085,7 +2098,7 @@ sa_rc_t sa_recv(sa_t *sa, sa_addr_t **raddr, char *buf, size_t buflen, size_t *b
         struct sockaddr_in6 sa6;
 #endif
     } sa_buf;
-    socklen_t sa_len;
+    socklen_t sa_size;
     size_t n;
     fd_set fds;
 
@@ -2117,15 +2130,15 @@ sa_rc_t sa_recv(sa_t *sa, sa_addr_t **raddr, char *buf, size_t buflen, size_t *b
     }
 
     /* perform receive operation on underlying socket */
-    sa_len = sizeof(sa_buf);
+    sa_size = sizeof(sa_buf);
     if ((n = SA_SC_CALL_6(sa, recvfrom, sa->fdSocket, buf, buflen, 0,
-                          (struct sockaddr *)&sa_buf, &sa_len)) == -1)
+                          (struct sockaddr *)&sa_buf, &sa_size)) == -1)
         return SA_RC(SA_ERR_SYS);
 
     /* create result address object */
     if ((rv = sa_addr_create(raddr)) != SA_OK)
         return rv;
-    if ((rv = sa_addr_s2a(*raddr, (struct sockaddr *)&sa_buf, sa_len)) != SA_OK) {
+    if ((rv = sa_addr_s2a(*raddr, (struct sockaddr *)&sa_buf, sa_size)) != SA_OK) {
         sa_addr_destroy(*raddr);
         return rv;
     }
@@ -2198,7 +2211,7 @@ sa_rc_t sa_sendf(sa_t *sa, sa_addr_t *raddr, const char *cpFmt, ...)
 
     /* format string into temporary buffer */
     va_start(ap, cpFmt);
-    nBuf = sa_mvsnprintf(NULL, NULL, cpFmt, ap);
+    nBuf = sa_mvsnprintf(NULL, 0, cpFmt, ap);
     va_end(ap);
     if ((nBuf+1) > sizeof(caBuf)) {
         /* requires a larger buffer, so allocate dynamically */
